uniform sampler2D inputTexture;
uniform float time;
uniform vec2 resolution;

varying vec2 vUv;
varying vec3 vNormal;  // Receive the normal data

void main() {
    // Distortion intensity varies with the normal's z-component
    float normalInfluence = abs(vNormal.z);  // Use the z-component of the normal for influence

    float waveAmplitude = 0.1 * normalInfluence;  // Modulate amplitude by normal
    float waveFrequency = 10.0;

    // Calculate distortion using a simple sine wave
    float distortion = waveAmplitude * sin(vUv.y * waveFrequency + time);

    // Apply the distortion to UV coordinates
    vec2 modUv = vUv;
    modUv.x += distortion;  // Distort along the x-axis

    vec4 textureColor = texture2D(inputTexture, modUv);
    gl_FragColor = vec4(textureColor.rgb, 1.0);
}
